@@ -35,6 +35,8 @@ from sparkmagic.utils.constants import LANG_SCALA, LANG_PYTHON
 
 IPYTHON_KERNEL = "IPythonKernel"
 PYSPARK_KERNEL = "PySparkKernel"
+SPARK_KERNEL = "SparkKernel"
+MAGIC_KERNELS = {PYSPARK_KERNEL, SPARK_KERNEL}
 SUCCESS = "SUCCESS"
 FAILURE = "FAILURE"
 LIBRARY_NAME = "sagemaker-analytics"
@@ -62,7 +64,6 @@ This method handles connectivity to EMR clusters from PySpark and SparkScala ker
 def _magic_kernel_connect_to_emr(
     emr_client, args, emr_cluster, username, password, kernel_name
 ):
-    # TODO: test against spark scala kernel
     print("Initiating EMR connection..")
     ipy = get_ipython()
     _run_preset_cell_magics(ipy)
@@ -103,8 +104,8 @@ def _get_endpoint_magic_line(
     )
 
     livy_endpoint = "http://{0}:{1}".format(livy_host, livy_port)
-    if kernel_name == PYSPARK_KERNEL:
-        return _get_pyspark_kernel_endpoint_magic_line(
+    if kernel_name in MAGIC_KERNELS:
+        return _get_magic_kernel_endpoint_magic_line(
             args=args,
             livy_endpoint=livy_endpoint,
             username=username,
@@ -263,7 +264,7 @@ def _handle_kerberos_connectivity_failure(args, completed_process):
         )
 
 
-def _get_pyspark_kernel_endpoint_magic_line(args, livy_endpoint, username, password):
+def _get_magic_kernel_endpoint_magic_line(args, livy_endpoint, username, password):
     if args.auth_type == "Basic_Access":
         return "-s {0} -t {1} -u {2} -p {3}".format(
             livy_endpoint, args.auth_type, username, password
@@ -379,11 +380,11 @@ def _get_livy_port_from_cluster_configuration(emr_cluster):
 def _validate_emr_args(args, usage, kernel_name):
     if args.cluster_id is None:
         raise ValueError(
-            "Missing required argument '{}'. {}".format("--cluster_id", usage)
+            "Missing required argument '{}'. {}".format("--cluster-id", usage)
         )
     elif args.auth_type is None:
         raise ValueError(
-            "Missing required argument '{}'. {}".format("--auth_type", usage)
+            "Missing required argument '{}'. {}".format("--auth-type", usage)
         )
     elif args.auth_type not in AUTH_TYPE_SET:
         raise Exception(
@@ -438,7 +439,7 @@ def _initiate_emr_connect(args, boto_session, kernel_name):
 def _initiate_connect_based_on_kernel(
     emr_client, args, emr_cluster, username, password, kernel_name
 ):
-    if kernel_name == PYSPARK_KERNEL:
+    if kernel_name in MAGIC_KERNELS:
         _magic_kernel_connect_to_emr(
             emr_client=emr_client,
             args=args,
@@ -521,7 +522,7 @@ class SagemakerAnalytics(Magics):
         ),
     )
     @argument(
-        "--auth_type",
+        "--auth-type",
         type=str,
         default=None,
         help="The authentication type to be used. Supported authentication types are {0}.".format(
@@ -529,7 +530,7 @@ class SagemakerAnalytics(Magics):
         ),
     )
     @argument(
-        "--cluster_id",
+        "--cluster-id",
         type=str,
         default=None,
         help="The cluster id to connect to.",
@@ -609,7 +610,7 @@ def _list_instance_groups(emr_client, cluster_id):
             emr_instance_group_list.extend(page["InstanceGroups"])
 
     except botocore.exceptions.ClientError as ce:
-        logger.debug(
+        logger.error(
             "Failed to list instance groups for EMR cluster({0}). {1}".format(
                 cluster_id, ce.response
             )
@@ -619,7 +620,6 @@ def _list_instance_groups(emr_client, cluster_id):
                 cluster_id, ce.response["Error"]
             )
         ) from None
-    logger.debug("List instance groups response: {0}".format(emr_instance_group_list))
     return emr_instance_group_list
 
 
